@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,23 +23,17 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
-
-$no_http_headers = true;
-
-include(dirname(__FILE__) . '/../include/global.php');
+require(__DIR__ . '/../include/cli_check.php');
 
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
-$table = '';
+$table  = '';
+$plugin = '';
 $create = true;
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
 			list($arg, $value) = explode('=', $parameter);
@@ -52,6 +46,9 @@ if (sizeof($parms)) {
 			case '--table':
 				$table = trim(sql_clean($value));
 				break;
+			case '--plugin':
+				$plugin = trim(sql_clean($value));
+				break;
 			case '--update':
 				$create = false;
 				break;
@@ -59,12 +56,12 @@ if (sizeof($parms)) {
 			case '-V':
 			case '-v':
 				display_version();
-				exit;
+				exit(0);
 			case '--help':
 			case '-H':
 			case '-h':
 				display_help();
-				exit;
+				exit(0);
 			default:
 
 		}
@@ -72,14 +69,14 @@ if (sizeof($parms)) {
 }
 
 if ($table == '') {
-	echo "ERROR: You must provide a table name\n";
+	print "ERROR: You must provide a table name\n";
 	display_help();
-	exit;
+	exit(1);
 } else {
-	echo sqltable_to_php($table, $create);
+	print sqltable_to_php($table, $create, $plugin);
 }
 
-function sqltable_to_php ($table, $create) {
+function sqltable_to_php($table, $create, $plugin = '') {
 	global $config, $database_default;
 
 	include_once($config['library_path'] . '/database.php');
@@ -89,14 +86,14 @@ function sqltable_to_php ($table, $create) {
 	$tables = array();
 	$text   = '';
 
-	if (sizeof($result)) {
+	if (cacti_sizeof($result)) {
 		foreach($result as $index => $arr) {
 			foreach ($arr as $t) {
 				$tables[] = $t;
 			}
 		}
 	} else {
-		echo "ERROR: Obtaining list of tables from $database_default\n";
+		print "ERROR: Obtaining list of tables from $database_default\n";
 		exit;
 	}
 
@@ -108,7 +105,7 @@ function sqltable_to_php ($table, $create) {
 		$keys   = array();
 		$text   = "\n\$data = array();\n";
 
-		if (sizeof($result)) {
+		if (cacti_sizeof($result)) {
 			foreach ($result as $r) {
 				$text .= "\$data['columns'][] = array(";
 				$text .= "'name' => '" . $r['Field'] . "'";
@@ -118,11 +115,13 @@ function sqltable_to_php ($table, $create) {
 					$text .= ", 'unsigned' => true";
 				}
 
-				$text .= ", 'type' => \"" . $r['Type'] . "\"";
+				$text .= ", 'type' => " . db_qstr($r['Type']);
 				$text .= ", 'NULL' => " . (strtolower($r['Null']) == 'no' ? 'false' : 'true');
 
 				if (trim($r['Default']) != '') {
 					$text .= ", 'default' => '" . $r['Default'] . "'";
+				} elseif (stripos($r['Type'], 'char') !== false) {
+					$text .= ", 'default' => ''";
 				}
 
 				if (trim($r['Extra']) != '') {
@@ -134,6 +133,7 @@ function sqltable_to_php ($table, $create) {
 						$text .= ", 'auto_increment' => true";
 					}
 				}
+
 				if (trim($r['Comment']) != '') {
 					$text .= ", 'comment' => '" . $r['Comment'] . "'";
 				}
@@ -141,12 +141,12 @@ function sqltable_to_php ($table, $create) {
 				$text .= ");\n";
 			}
 		} else {
-			echo "ERROR: Obtaining list of columns from $table\n";
+			print "ERROR: Obtaining list of columns from $table\n";
 			exit;
 		}
 
 		$result = db_fetch_assoc("SHOW INDEX FROM $table");
-		if (sizeof($result)) {
+		if (cacti_sizeof($result)) {
 			foreach ($result as $r) {
 				if ($r['Key_name'] == 'PRIMARY') {
 					$pri[] = $r['Column_name'];
@@ -156,30 +156,48 @@ function sqltable_to_php ($table, $create) {
 			}
 
 			if (!empty($pri)) {
-				$text .= "\$data['primary'] = array('" . implode("','", $pri) . "');\n";
+				if ($plugin != '' || $create) {
+					$text .= "\$data['primary'] = '" . implode("`,`", $pri) . "';\n";
+				} else {
+					$text .= "\$data['primary'] = array('" . implode("','", $pri) . "');\n";
+				}
 			}
 
 			if (!empty($keys)) {
 				foreach ($keys as $n => $k) {
-					$text .= "\$data['keys'][] = array('name' => '$n', 'columns' => array('" . implode("','", $k) . "'));\n";
+					if ($plugin != '') {
+						$text .= "\$data['keys'][] = array('name' => '$n', 'columns' => '" . implode("`,`", $k) . "');\n";
+					} else {
+						$text .= "\$data['keys'][] = array('name' => '$n', 'columns' => array('" . implode("','", $k) . "'));\n";
+					}
 				}
 			}
 		} else {
-			//echo "ERROR: Obtaining list of indexes from $table\n";
+			//print "ERROR: Obtaining list of indexes from $table\n";
 			//exit;
 		}
 
-		$result = db_fetch_row("SELECT ENGINE, TABLE_COMMENT FROM information_schema.TABLES WHERE TABLE_NAME = '$table'");
-		if (sizeof($result)) {
+		$result = db_fetch_row_prepared('select ENGINE, TABLE_COMMENT, ROW_FORMAT
+			FROM information_schema.TABLES
+			WHERE TABLE_SCHEMA = SCHEMA()
+			AND TABLE_NAME = ?',
+			array($table));
+
+		if (cacti_sizeof($result)) {
 			$text .= "\$data['type'] = '" . $result['ENGINE'] . "';\n";
 			$text .= "\$data['comment'] = '" . $result['TABLE_COMMENT'] . "';\n";
+			$text .= "\$data['row_format'] = '" . $result['ROW_FORMAT'] . "';\n";
 			if ($create) {
-				$text .= "db_table_create ('$table', \$data);\n";
+				if ($plugin != '') {
+					$text .= "api_plugin_db_table_create ('$plugin', '$table', \$data);\n";
+				} else {
+					$text .= "db_table_create ('$table', \$data);\n";
+				}
 			} else {
 				$text .= "db_update_table ('$table', \$data, false);\n";
 			}
 		} else {
-			echo "ERROR: Unable to get tables details from Information Schema\n";
+			print "ERROR: Unable to get tables details from Information Schema\n";
 			exit;
 		}
 	}
@@ -194,22 +212,25 @@ function sql_clean($text) {
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = get_cacti_version();
-	echo "Cacti Add Device Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+	$version = get_cacti_cli_version();
+	print "Cacti SQL to PHP Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
 function display_help() {
-    display_version();
+	display_version();
 
-    echo "\nusage: sqltable_to_php.php --table=table_name [--update]\n\n";
-    echo "A simple developers utility to create a save schema for a newly created or\n";
-	echo "modified database table.  These save schema's can be placed into a plugins\n";
-	echo "setup.php file in order to create the tables inside of a plugin as a part of\n";
-	echo "it's install function.\n\n";
-	echo "Required:\n";
-	echo "--table=table_name - The table that you want exportred\n\n";
-	echo "Optional:\n";
-	echo "--update           - The utility provides create syntax.  If the update flag is\n";
-	echo "                     specified, the utility will provide update syntax\n\n";
+	print "\nusage: sqltable_to_php.php --table=table_name [--plugin=name] [--update]\n\n";
+	print "A simple developers utility to create a save schema for a newly created or\n";
+	print "modified database table in a format that is consumable by Cacti.\n\n";
+	print "These save schema's can be placed into a plugins setup.php file in order\n";
+	print "to create the tables inside of a plugin as a part of it's install function.\n";
+	print "The plugin parameter is optional, but if you want the table(s) automatically\n";
+	print "removed from Cacti when uninstalling the plugin, specify it's name.\n\n";
+	print "Required:\n";
+	print "--table=table_name - The table that you want exportred\n\n";
+	print "Optional:\n";
+	print "--plugin=name      - The name of the plugin that will manage tables\n";
+	print "--update           - The utility provides create syntax.  If the update flag is\n";
+	print "                     specified, the utility will provide update syntax\n\n";
 }
 
